@@ -4,14 +4,19 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Patches to Net::Server::PreFork
-our $VERSION = '2.20201209.2'; # VERSION
+our $VERSION = '2.20210105.2'; # VERSION
 use base 'Net::Server::PreFork';
 use POSIX qw(EINTR);
+use SUPER;
 use Socket qw(AF_INET AF_UNIX SOCK_DGRAM SOCK_STREAM);
 
 
 sub run_child {
     my $self = shift;
+
+    my $config = $self->{config} || get_config();
+    return $self->SUPER unless $config->{'patch_net_server'};
+
     my $prop = $self->{'server'};
 
     $SIG{'INT'} = $SIG{'TERM'} = $SIG{'QUIT'} = sub {
@@ -70,6 +75,10 @@ sub run_child {
 
 sub accept { ## no critic
     my $self = shift;
+
+    my $config = $self->{config} || get_config();
+    return $self->SUPER unless $config->{'patch_net_server'};
+
     my $prop = $self->{'server'};
 
     if ($prop->{'serialize'} eq 'flock') {
@@ -143,6 +152,10 @@ sub super_accept {
 
 sub accept_multi_port {
     my $self = shift;
+
+    my $config = $self->{config} || get_config();
+    return $self->SUPER unless $config->{'patch_net_server'};
+
     my $prop = $self->{'server'};
     while (1) {
       my @waiting = $prop->{'select'}->can_read();
@@ -167,7 +180,7 @@ Mail::Milter::Authentication::Net::ServerPatches - Patches to Net::Server::PreFo
 
 =head1 VERSION
 
-version 2.20201209.2
+version 2.20210105.2
 
 =head1 METHODS
 
